﻿/*
 * Copyright (C) 2020 Tilt Five, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System.Collections;
using System.Collections.Generic;
using UnityEngine;

namespace TiltFiveDemos
{
    /// <summary>
    /// Compensates the gravity in the scene for a reference object,
    /// So that the object represents 1 unit in the default unity gravity,
    /// also multiplied by an arbitrary amount for more tweaking.
    /// </summary>
    public class ObjectCompensateGravity : MonoBehaviour
    {
        /// <summary>
        /// An arbitrary gravity multiplier. 
        /// By default 1.
        /// </summary>
        [SerializeField]
        private float _gravityMultiplier = 1f;

        // Start is called before the first frame update
        void Start()
        {
            float scale = transform.lossyScale.y;

            Vector3 gravity = Physics.gravity;

            Vector3 newGravity = (gravity * scale) * _gravityMultiplier;

            Physics.gravity = newGravity;
        }
    }
}
